## Product details

KDD LED desk lamp it integrates a desk lamp, pen holder, phone stand, charging ports, and device slot. The light source adjustment is flexible, with warm light and mixed light modes. The brightness of the mixed light can be set to three levels: 100%, 50%, and 20%, and it also has a built-in brightness memory function. Equipped with a 360° flexible gooseneck design, the angle and height of the lamp can be adjusted freely. In addition, the desk lamp is equipped with USB and Type-C ports; the base has 6 rubber non-slip pads, which keep it stable without wobbling and also protect the desktop.
【 Light Source Adjustment】 LED Desk Lamp features warm light and mixed light modes. The brightness of the mixed light can be adjusted to three levels: 100%, 50%, and 20%, and it comes with a brightness memory function.
【360° Gooseneck Design】 The LED soft lighting is combined with a flexible gooseneck design, allowing free adjustment of the lamp's angle and height to easily direct light precisely to the area you need.
【Built-in Charging Station】 Desk Lamp is equipped with USB and Type-C ports (Note: The Type-C port is not compatible with iPhone charging), which can charge multiple electronic devices such as mobile phones and tablets at the same time.
【Non-Slip Base】 The base of the desk lamp is equipped with 6 rubber non-slip pads, which ensure the overall stability while preventing scratches on the desktop.
【Storage Space Design】 KDD Desk Lamp integrates a desk lamp, pen holder, phone stand, charging ports, and device slot into one, meeting your needs for lighting, stationery storage, electronic device placement, and charging in one stop.
↓↓↓
Specification
Brands: KDD
Color: Black
Size: 10.63 x 5.51 x 20.08 in
Weight: 1.72lb
Package List: Desk lamp, instruction manual
↓↓↓ Tip: If you encounter any quality issues with the product, please contact us via the store email address. Thank you!
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Features
Dimmable, Adjustable Head, Energy Efficient, USB Port
Light bulb type
LED
Lamp style
Gooseneck
Color type
Black
More details
## Warranty

Warranty information
Please be aware that the warranty terms on items offered for sale by third party Marketplace sellers may differ from those displayed in this section (if any). To confirm warranty terms on an item offered for sale by a third party Marketplace seller, please use the 'Contact seller' feature on the third party Marketplace seller's information page and request the item's warranty terms prior to purchase.
